NOTEBOOK_TRAINER_PREFIX = r"#[^\S\n\t]*keep[^\S\n\t]*\n*$"
DEFAULT_TRAINER_TIMEOUT_S = 60 * 5
MODEL_ROUTE_URI = r"([a-zA-Z0-9\-\_]+)/([a-zA-Z0-9\-\_]+)/?([a-zA-Z0-9\-\_]*)"
DATASET_IO_THREAD_COUNT = 8
